==> paragraph_group-3.0.x-dev.zip: paragraph_group/libraries/settings/settings.js <==
function paragroup($) {
  const functions = {
    /**
     * Open a Details element.
     * @param {string} id - The ID selector of the Details element to open
     */
    openDetails(id) {
      const $detailsEl = $(id);

      if (!$detailsEl.attr('open')) {
        $detailsEl.attr('open', '');
      }
    },

    /**
     * Clicks the select-all input for a configuration section.
     * @param {string} sectionId - The ID selector of the configuration section
     * @param {boolean} deselect - Whether to deselect all rows (default: false)
     */
    clickSelectAll(sectionId, deselect = false) {
      const $selectAll = $(`${sectionId} th.select-all input`);
      const title = $selectAll.attr('title');
      let titleComparison = null;

      if (!deselect) {
        titleComparison = 'Select all rows in this table';
      } else {
        titleComparison = 'Deselect all rows in this table';
      }

      if (title === titleComparison) {
        $selectAll.click();
      }
    },

    /**
     * Set up main sections checkboxes.
     */
    mainSections() {
      const sections = [
        '#edit-details-widget-boxes',
        '#edit-admin-titles-boxes',
        '#edit-field-groups-boxes',
      ];

      $.each(sections, functions.processSection);
    },

    /**
     * Set up theme mods checkboxes.
     */
    themeMods() {
      const themeModsId = '#edit-theme-mods-boxes';

      functions.clickSelectAll(themeModsId, true);

      $('#edit-theme-mods-boxes-full-width-forms').prop('checked', true);
      $('#edit-theme-mods-boxes-sidebar-config')
        .removeAttr('disabled')
        .prop('checked', false);

      functions.openDetails(themeModsId);
    },

    /**
     * When "clicking here" link is clicked, sets up recommended configuration.
     */
    recommendedConfig() {
      $('#pg-rec-config-link').click(functions.handleRecommendedConfig);
    },

    /**
     * Action for disabling / preventing clicks on sidebar config checkbox,
     * used in function below this one.
     */
    scAction() {
      const $sc = $('#edit-theme-mods-boxes-sidebar-config');
      const $fwf = $('#edit-theme-mods-boxes-full-width-forms');

      if ($fwf.prop('checked')) {
        $sc.removeAttr('disabled');
      } else {
        $sc.prop('checked', false).attr('disabled', true);
      }
    },

    /**
     * Prevents 'Move page configuration sidebar to bottom of edit pages'
     * config checkbox from being checked, without 'Full Width Forms'
     * checkbox being checked first.
     */
    sidebarConfig() {
      functions.scAction();
      $('#edit-theme-mods-boxes-full-width-forms').change(functions.scAction);
    },

    /**
     * Adds class to html element confirming module has completed initialising.
     * @param {string} className - The CSS class name to add to the html element
     */
    addClassToHtml(className) {
      const $html = $('html');

      if (!$html.hasClass(className)) {
        $html.addClass(className);
      }
    },

    /**
     * Main function containing all functionality in this file.
     */
    main() {
      const $sa = $('#edit-theme-mods-boxes th.select-all input');

      if ($sa.length && !$('html').hasClass('pg-settings-complete')) {
        functions.recommendedConfig();
        functions.sidebarConfig();
        functions.addClassToHtml('pg-settings-complete');
      }
    },

    /**
     * Processes each section for recommended configuration.
     * @param {number} index - The index from jQuery each
     * @param {string} id - The section ID
     */
    processSection(index, id) {
      functions.clickSelectAll(id);
      functions.openDetails(id);
    },

    /**
     * Handles recommended configuration link click event.
     * @param {Event} event - The click event
     */
    handleRecommendedConfig(event) {
      event.preventDefault();
      functions.mainSections();
      functions.themeMods();
    },
  };

  functions.main();
}

(function initializeParagroupSettings($) {
  Drupal.behaviors.paragraph_group = {
    attach: function attach(context, settings) {
      if (settings.hasOwnProperty('paragraph_group_settings')) {
        paragroup($);
      }
    },
  };
})(jQuery);

==> paragraph_group-3.1.x-dev.zip: paragraph_group/libraries/settings/settings.js <==
function paragroup($) {
  const functions = {
    openDetails(id) {
      const $detailsEl = $(id);
      if (!$detailsEl.attr('open')) {
        $detailsEl.attr('open', '');
      }
    },
    clickSelectAll(sectionId, deselect = false) {
      const $selectAll = $(`${sectionId} th.select-all input`);
      const title = $selectAll.attr('title');
      let titleComparison = null;
      if (!deselect) {
        titleComparison = 'Select all rows in this table';
      } else {
        titleComparison = 'Deselect all rows in this table';
      }
      if (title === titleComparison) {
        $selectAll.click();
      }
    },
    mainSections() {
      const sections = [
        '#edit-details-widget-boxes',
        '#edit-admin-titles-boxes',
        '#edit-field-groups-boxes',
      ];
      $.each(sections, functions.processSection);
    },
    themeMods() {
      const themeModsId = '#edit-theme-mods-boxes';
      functions.clickSelectAll(themeModsId, true);
      $('#edit-theme-mods-boxes-full-width-forms').prop('checked', true);
      $('#edit-theme-mods-boxes-sidebar-config')
        .removeAttr('disabled')
        .prop('checked', false);
      functions.openDetails(themeModsId);
    },
    recommendedConfig() {
      $('#pg-rec-config-link').click(functions.handleRecommendedConfig);
    },
    scAction() {
      const $sc = $('#edit-theme-mods-boxes-sidebar-config');
      const $fwf = $('#edit-theme-mods-boxes-full-width-forms');
      if ($fwf.prop('checked')) {
        $sc.removeAttr('disabled');
      } else {
        $sc.prop('checked', false).attr('disabled', 'disabled');
      }
    },
    sidebarConfig() {
      functions.scAction();
      $('#edit-theme-mods-boxes-full-width-forms').change(functions.scAction);
    },
    addClassToHtml(className) {
      const $html = $('html');
      if (!$html.hasClass(className)) {
        $html.addClass(className);
      }
    },
    main() {
      const $sa = $('#edit-theme-mods-boxes th.select-all input');
      if ($sa.length && !$('html').hasClass('pg-settings-complete')) {
        functions.recommendedConfig();
        functions.sidebarConfig();
        functions.addClassToHtml('pg-settings-complete');
      }
    },
    processSection(index, id) {
      functions.clickSelectAll(id);
      functions.openDetails(id);
    },
    handleRecommendedConfig(event) {
      event.preventDefault();
      functions.mainSections();
      functions.themeMods();
    },
  };
  functions.main();
}
(function initializeParagroupSettings($) {
  Drupal.behaviors.paragraph_group = {
    attach(context, settings) {
      if (settings.hasOwnProperty('paragraph_group_settings')) {
        paragroup($);
      }
    },
  };
})(jQuery);
